Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(26)

Unified Diff: src/IceRegistersMIPS32.h

Issue 1159823004: First patch for Mips subzero compiler (Closed) Base URL: https://chromium.googlesource.com/native_client/pnacl-subzero.git@master
Patch Set: Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/IceRegistersMIPS32.h
diff --git a/src/IceRegistersARM32.h b/src/IceRegistersMIPS32.h
similarity index 77%
copy from src/IceRegistersARM32.h
copy to src/IceRegistersMIPS32.h
index 2ad1c8b36adef2dfb57836cd13efb255f2b47347..b78282bf0eda3501b08ad978a9e87cb3393a8870 100644
--- a/src/IceRegistersARM32.h
+++ b/src/IceRegistersMIPS32.h
@@ -1,4 +1,4 @@
-//===- subzero/src/IceRegistersARM32.h - Register information ---*- C++ -*-===//
+//===- subzero/src/IceRegistersMIPS32.h - Register information ---*- C++ -*-===//
Jim Stichnoth 2015/05/30 00:47:14 remove a '-' to maintain 80-col
//
// The Subzero Code Generator
//
@@ -7,20 +7,20 @@
//
//===----------------------------------------------------------------------===//
//
// This file declares the registers and their encodings for ARM32.
//
//===----------------------------------------------------------------------===//
-#ifndef SUBZERO_SRC_ICEREGISTERSARM32_H
-#define SUBZERO_SRC_ICEREGISTERSARM32_H
+#ifndef SUBZERO_SRC_ICEREGISTERSMIPS32_H
+#define SUBZERO_SRC_ICEREGISTERSMIPS32_H
#include "IceDefs.h"
-#include "IceInstARM32.def"
+#include "IceInstMIPS32.def"
#include "IceTypes.h"
namespace Ice {
-namespace RegARM32 {
+namespace RegMIPS32 {
// An enum of every register. The enum value may not match the encoding
// used to binary encode register operands in instructions.
@@ -28,11 +28,11 @@ enum AllRegisters {
#define X(val, encode, name, scratch, preserved, stackptr, frameptr, isInt, \
isFP) \
val,
- REGARM32_TABLE
+ REGMIPS32_TABLE
#undef X
Reg_NUM,
#define X(val, init) val init,
- REGARM32_TABLE_BOUNDS
+ REGMIPS32_TABLE_BOUNDS
#undef X
};
@@ -42,7 +42,7 @@ enum GPRRegister {
#define X(val, encode, name, scratch, preserved, stackptr, frameptr, isInt, \
isFP) \
Encoded_##val encode,
- REGARM32_GPR_TABLE
+ REGMIPS32_GPR_TABLE
#undef X
Encoded_Not_GPR = -1
};
@@ -55,8 +55,8 @@ static inline GPRRegister getEncodedGPR(int32_t RegNum) {
return GPRRegister(RegNum - Reg_GPR_First);
}
-} // end of namespace RegARM32
+} // end of namespace RegMIPS32
} // end of namespace Ice
-#endif // SUBZERO_SRC_ICEREGISTERSARM32_H
+#endif // SUBZERO_SRC_ICEREGISTERSMIPS32_H

Powered by Google App Engine
This is Rietveld 408576698
@@ -7,20 +7,20 @@
//===----------------------------------------------------------------------===//
//
-// This file declares the registers and their encodings for ARM32.
+// This file declares the registers and their encodings for MIPS32.
//
//===----------------------------------------------------------------------===//